@@ -8,19 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_autoscaling._jsii
-import aws_cdk.aws_cloudwatch._jsii
-import aws_cdk.aws_elasticache._jsii
-import aws_cdk.aws_elasticloadbalancingv2._jsii
-import aws_cdk.aws_rds._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "halloumi-cloudwatch-dashboard",
-    "1.1.0",
+    "2.0.0",
     __name__[0:-6],
-    "halloumi-cloudwatch-dashboard@1.1.0.jsii.tgz",
+    "halloumi-cloudwatch-dashboard@2.0.0.jsii.tgz",
 )
 
 __all__ = [
